@@ -7,12 +7,12 @@ from datahub.api.entities.datajob import DataFlow
 from datahub.api.entities.dataprocess.dataprocess_instance import (
     DataProcessInstance, InstanceRunResult)
 
-from metadata.entity.workflow import WorkFlow
+from metadata.entity.workflow import Workflow
 
 
 class WorkflowMixin:
 
-    def prepare_workflow(self, workflow: WorkFlow):
+    def prepare_workflow(self, workflow: Workflow):
         dataflow = DataFlow(
             id=workflow.id,
             name=workflow.name,
